# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'main.ui'
#
# Created by: PyQt5 UI code generator 5.14.2
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets
import os

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setWindowIcon(QtGui.QIcon(f"{os.path.dirname(os.path.realpath(__file__))}/icons/icon256.png"))
        MainWindow.setObjectName("MainWindow")
        MainWindow.setEnabled(True)
        MainWindow.setFixedSize(630, 280)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(9)
        MainWindow.setFont(font)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.mailDomainInput = QtWidgets.QLineEdit(self.centralwidget)
        self.mailDomainInput.setEnabled(False)
        self.mailDomainInput.setGeometry(QtCore.QRect(30, 190, 251, 25))
        self.mailDomainInput.setObjectName("mailDomainInput")
        self.atLabel = QtWidgets.QLabel(self.centralwidget)
        self.atLabel.setEnabled(True)
        self.atLabel.setGeometry(QtCore.QRect(10, 190, 21, 21))
        font = QtGui.QFont()
        font.setPointSize(12)
        self.atLabel.setFont(font)
        self.atLabel.setObjectName("atLabel")
        self.verticalLayoutWidget = QtWidgets.QWidget(self.centralwidget)
        self.verticalLayoutWidget.setGeometry(QtCore.QRect(10, 40, 271, 141))
        self.verticalLayoutWidget.setObjectName("verticalLayoutWidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.verticalLayoutWidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.radioE2U = QtWidgets.QRadioButton(self.verticalLayoutWidget)
        self.radioE2U.setEnabled(False)
        self.radioE2U.setObjectName("radioE2U")
        self.buttonGroup = QtWidgets.QButtonGroup(MainWindow)
        self.buttonGroup.setObjectName("buttonGroup")
        self.buttonGroup.addButton(self.radioE2U)
        self.verticalLayout.addWidget(self.radioE2U)
        self.radioEP2UP = QtWidgets.QRadioButton(self.verticalLayoutWidget)
        self.radioEP2UP.setEnabled(False)
        self.radioEP2UP.setObjectName("radioEP2UP")
        self.buttonGroup.addButton(self.radioEP2UP)
        self.verticalLayout.addWidget(self.radioEP2UP)
        self.radioU2E = QtWidgets.QRadioButton(self.verticalLayoutWidget)
        self.radioU2E.setEnabled(False)
        self.radioU2E.setObjectName("radioU2E")
        self.buttonGroup.addButton(self.radioU2E)
        self.verticalLayout.addWidget(self.radioU2E)
        self.radioUP2EP = QtWidgets.QRadioButton(self.verticalLayoutWidget)
        self.radioUP2EP.setEnabled(False)
        self.radioUP2EP.setObjectName("radioUP2EP")
        self.buttonGroup.addButton(self.radioUP2EP)
        self.verticalLayout.addWidget(self.radioUP2EP)
        self.importBtn = QtWidgets.QPushButton(self.centralwidget)
        self.importBtn.setGeometry(QtCore.QRect(10, 10, 271, 25))
        self.importBtn.setObjectName("importBtn")
        self.convertBtn = QtWidgets.QPushButton(self.centralwidget)
        self.convertBtn.setEnabled(False)
        self.convertBtn.setGeometry(QtCore.QRect(10, 220, 271, 31))
        self.convertBtn.setObjectName("convertBtn")
        self.textArea = QtWidgets.QPlainTextEdit(self.centralwidget)
        self.textArea.setGeometry(QtCore.QRect(290, 10, 329, 211))
        self.textArea.setObjectName("textArea")
        self.horizontalLayoutWidget = QtWidgets.QWidget(self.centralwidget)
        self.horizontalLayoutWidget.setGeometry(QtCore.QRect(290, 230, 331, 27))
        self.horizontalLayoutWidget.setObjectName("horizontalLayoutWidget")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.horizontalLayoutWidget)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.saveTxtBtn = QtWidgets.QPushButton(self.horizontalLayoutWidget)
        self.saveTxtBtn.setObjectName("saveTxtBtn")
        self.horizontalLayout.addWidget(self.saveTxtBtn)
        self.copyTxtBtn = QtWidgets.QPushButton(self.horizontalLayoutWidget)
        self.copyTxtBtn.setObjectName("copyTxtBtn")
        self.horizontalLayout.addWidget(self.copyTxtBtn)
        self.clearTxtBtn = QtWidgets.QPushButton(self.horizontalLayoutWidget)
        self.clearTxtBtn.setObjectName("clearTxtBtn")
        self.horizontalLayout.addWidget(self.clearTxtBtn)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 628, 22))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuEdit = QtWidgets.QMenu(self.menubar)
        self.menuEdit.setObjectName("menuEdit")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        MainWindow.setMenuBar(self.menubar)
        self.actionCopy = QtWidgets.QAction(MainWindow)
        self.actionCopy.setCheckable(False)
        self.actionCopy.setObjectName("actionCopy")
        self.actionCut = QtWidgets.QAction(MainWindow)
        self.actionCut.setObjectName("actionCut")
        self.actionPaste = QtWidgets.QAction(MainWindow)
        self.actionPaste.setObjectName("actionPaste")
        self.actionUndo = QtWidgets.QAction(MainWindow)
        self.actionUndo.setObjectName("actionUndo")
        self.actionRedo = QtWidgets.QAction(MainWindow)
        self.actionRedo.setObjectName("actionRedo")
        self.mb_import = QtWidgets.QAction(MainWindow)
        self.mb_import.setObjectName("mb_import")
        self.mb_save = QtWidgets.QAction(MainWindow)
        self.mb_save.setEnabled(False)
        self.mb_save.setObjectName("mb_save")
        self.mb_undo = QtWidgets.QAction(MainWindow)
        self.mb_undo.setObjectName("mb_undo")
        self.mb_redo = QtWidgets.QAction(MainWindow)
        self.mb_redo.setObjectName("mb_redo")
        self.mb_cut = QtWidgets.QAction(MainWindow)
        self.mb_cut.setObjectName("mb_cut")
        self.mb_copy = QtWidgets.QAction(MainWindow)
        self.mb_copy.setObjectName("mb_copy")
        self.mb_paste = QtWidgets.QAction(MainWindow)
        self.mb_paste.setObjectName("mb_paste")
        self.mb_about = QtWidgets.QAction(MainWindow)
        self.mb_about.setIconVisibleInMenu(True)
        self.mb_about.setObjectName("mb_about")
        self.mb_howto = QtWidgets.QAction(MainWindow)
        self.mb_howto.setObjectName("mb_howto")
        self.mb_report = QtWidgets.QAction(MainWindow)
        self.mb_report.setObjectName("mb_report")
        self.menuFile.addAction(self.mb_import)
        self.menuFile.addAction(self.mb_save)
        self.menuEdit.addAction(self.mb_undo)
        self.menuEdit.addAction(self.mb_redo)
        self.menuEdit.addSeparator()
        self.menuEdit.addAction(self.mb_cut)
        self.menuEdit.addAction(self.mb_copy)
        self.menuEdit.addAction(self.mb_paste)
        self.menuHelp.addAction(self.mb_about)
        self.menuHelp.addAction(self.mb_howto)
        self.menuHelp.addAction(self.mb_report)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuEdit.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("UserMail Converter", "UserMail Converter"))
        self.mailDomainInput.setPlaceholderText(_translate("MainWindow", "eg: gmail.com"))
        self.atLabel.setText(_translate("MainWindow", "@"))
        self.radioE2U.setText(_translate("MainWindow", "Email > Username"))
        self.radioEP2UP.setText(_translate("MainWindow", "Email:Pass > Username:Pass"))
        self.radioU2E.setText(_translate("MainWindow", "Username > Email"))
        self.radioUP2EP.setText(_translate("MainWindow", "Username:Pass > Email:Pass"))
        self.importBtn.setText(_translate("MainWindow", "Import File"))
        self.convertBtn.setText(_translate("MainWindow", "Convert"))
        self.textArea.setPlaceholderText(_translate("MainWindow", "paste list here or import a file"))
        self.saveTxtBtn.setText(_translate("MainWindow", "Save"))
        self.copyTxtBtn.setText(_translate("MainWindow", "Copy"))
        self.clearTxtBtn.setText(_translate("MainWindow", "Clear"))
        self.menuFile.setTitle(_translate("MainWindow", "File"))
        self.menuEdit.setTitle(_translate("MainWindow", "Edit"))
        self.menuHelp.setTitle(_translate("MainWindow", "Help"))
        self.actionCopy.setText(_translate("MainWindow", "Copy"))
        self.actionCopy.setShortcut(_translate("MainWindow", "Ctrl+C"))
        self.actionCut.setText(_translate("MainWindow", "Cut"))
        self.actionCut.setShortcut(_translate("MainWindow", "Ctrl+X"))
        self.actionPaste.setText(_translate("MainWindow", "Paste"))
        self.actionPaste.setShortcut(_translate("MainWindow", "Ctrl+V"))
        self.actionUndo.setText(_translate("MainWindow", "Undo"))
        self.actionRedo.setText(_translate("MainWindow", "Redo"))
        self.mb_import.setText(_translate("MainWindow", "Import File"))
        self.mb_import.setShortcut(_translate("MainWindow", "Ctrl+I"))
        self.mb_save.setText(_translate("MainWindow", "Save As..."))
        self.mb_save.setShortcut(_translate("MainWindow", "Ctrl+S"))
        self.mb_undo.setText(_translate("MainWindow", "Undo"))
        self.mb_undo.setShortcut(_translate("MainWindow", "Ctrl+Z"))
        self.mb_redo.setText(_translate("MainWindow", "Redo"))
        self.mb_redo.setShortcut(_translate("MainWindow", "Ctrl+Y"))
        self.mb_cut.setText(_translate("MainWindow", "Cut"))
        self.mb_cut.setShortcut(_translate("MainWindow", "Ctrl+X"))
        self.mb_copy.setText(_translate("MainWindow", "Copy"))
        self.mb_copy.setShortcut(_translate("MainWindow", "Ctrl+C"))
        self.mb_paste.setText(_translate("MainWindow", "Paste"))
        self.mb_paste.setShortcut(_translate("MainWindow", "Ctrl+V"))
        self.mb_about.setText(_translate("MainWindow", "About"))
        self.mb_howto.setText(_translate("MainWindow", "How To"))
        self.mb_report.setText(_translate("MainWindow", "Report Issue"))
